pub struct RequestFinalizeBlock {
pub txs: Vec<Bytes>,
pub decided_last_commit: Option<CommitInfo>,
pub misbehavior: Vec<Misbehavior>,
pub hash: Bytes,
pub height: i64,
pub time: Option<Timestamp>,
pub next_validators_hash: Bytes,
pub proposer_address: Bytes,
}Fields
txs: Vec<Bytes>decided_last_commit: Option<CommitInfo>misbehavior: Vec<Misbehavior>hash: Byteshash is the merkle root hash of the fields of the decided block.
height: i64time: Option<Timestamp>next_validators_hash: Bytesproposer_address: Bytesproposer_address is the address of the public key of the original proposer of the block.