pub struct RequestProcessProposal {
pub txs: Vec<Bytes>,
pub proposed_last_commit: Option<CommitInfo>,
pub misbehavior: Vec<Misbehavior>,
pub hash: Bytes,
pub height: i64,
pub time: Option<Timestamp>,
pub next_validators_hash: Bytes,
pub proposer_address: Bytes,
}Fields
txs: Vec<Bytes>proposed_last_commit: Option<CommitInfo>misbehavior: Vec<Misbehavior>hash: Byteshash is the merkle root hash of the fields of the proposed block.
height: i64time: Option<Timestamp>next_validators_hash: Bytesproposer_address: Bytesaddress of the public key of the original proposer of the block.