pub struct State {Show 14 fields
pub version: Option<Version>,
pub chain_id: String,
pub initial_height: i64,
pub last_block_height: i64,
pub last_block_id: Option<BlockId>,
pub last_block_time: Option<Timestamp>,
pub next_validators: Option<ValidatorSet>,
pub validators: Option<ValidatorSet>,
pub last_validators: Option<ValidatorSet>,
pub last_height_validators_changed: i64,
pub consensus_params: Option<ConsensusParams>,
pub last_height_consensus_params_changed: i64,
pub last_results_hash: Vec<u8>,
pub app_hash: Vec<u8>,
}Fields
version: Option<Version>chain_id: Stringimmutable
initial_height: i64last_block_height: i64LastBlockHeight=0 at genesis (ie. block(H=0) does not exist)
last_block_id: Option<BlockId>last_block_time: Option<Timestamp>next_validators: Option<ValidatorSet>LastValidators is used to validate block.LastCommit. Validators are persisted to the database separately every time they change, so we can query for historical validator sets. Note that if s.LastBlockHeight causes a valset change, we set s.LastHeightValidatorsChanged = s.LastBlockHeight + 1 + 1 Extra +1 due to nextValSet delay.
validators: Option<ValidatorSet>last_validators: Option<ValidatorSet>last_height_validators_changed: i64consensus_params: Option<ConsensusParams>Consensus parameters used for validating blocks. Changes returned by EndBlock and updated after Commit.
last_height_consensus_params_changed: i64last_results_hash: Vec<u8>Merkle root of the results from executing prev block
app_hash: Vec<u8>the latest AppHash we’ve received from calling abci.Commit()