pub struct ExtendedCommitSig {
pub block_id_flag: i32,
pub validator_address: Vec<u8>,
pub timestamp: Option<Timestamp>,
pub signature: Vec<u8>,
pub extension: Vec<u8>,
pub extension_signature: Vec<u8>,
}Expand description
ExtendedCommitSig retains all the same fields as CommitSig but adds vote extension-related fields. We use two signatures to ensure backwards compatibility. That is the digest of the original signature is still the same in prior versions
Fields
block_id_flag: i32validator_address: Vec<u8>timestamp: Option<Timestamp>signature: Vec<u8>extension: Vec<u8>Vote extension data
extension_signature: Vec<u8>Vote extension signature
Implementations
Sourceimpl ExtendedCommitSig
impl ExtendedCommitSig
Sourcepub fn block_id_flag(&self) -> BlockIdFlag
pub fn block_id_flag(&self) -> BlockIdFlag
Returns the enum value of block_id_flag, or the default if the field is set to an invalid enum value.
Sourcepub fn set_block_id_flag(&mut self, value: BlockIdFlag)
pub fn set_block_id_flag(&mut self, value: BlockIdFlag)
Sets block_id_flag to the provided enum value.