pub struct Vote {
pub type: i32,
pub height: i64,
pub round: i32,
pub block_id: Option<BlockId>,
pub timestamp: Option<Timestamp>,
pub validator_address: Vec<u8>,
pub validator_index: i32,
pub signature: Vec<u8>,
pub extension: Vec<u8>,
pub extension_signature: Vec<u8>,
}Expand description
Vote represents a prevote or precommit vote from validators for consensus.
Fields
type: i32height: i64round: i32block_id: Option<BlockId>zero if vote is nil.
timestamp: Option<Timestamp>validator_address: Vec<u8>validator_index: i32signature: Vec<u8>Vote signature by the validator if they participated in consensus for the associated block.
extension: Vec<u8>Vote extension provided by the application. Only valid for precommit messages.
extension_signature: Vec<u8>Vote extension signature by the validator if they participated in consensus for the associated block. Only valid for precommit messages.
Implementations
Sourceimpl Vote
impl Vote
Sourcepub fn type(&self) -> SignedMsgType
pub fn type(&self) -> SignedMsgType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: SignedMsgType)
pub fn set_type(&mut self, value: SignedMsgType)
Sets type to the provided enum value.